==> mongodb-0.9.4-4.tgz: package/test/remove_test.js <==
var mongodb = process.env['TEST_NATIVE'] != null ? require('../lib/mongodb').native() : require('../lib/mongodb').pure();

var testCase = require('../deps/nodeunit').testCase,
  debug = require('util').debug
  inspect = require('util').inspect,
  nodeunit = require('../deps/nodeunit'),
  Db = mongodb.Db,
  Cursor = mongodb.Cursor,
  Collection = mongodb.Collection,
  Server = mongodb.Server;

var MONGODB = 'integration_tests';
var client = new Db(MONGODB, new Server("127.0.0.1", 27017, {auto_reconnect: false, native_parser: (process.env['TEST_NATIVE'] != null) ? true : false}));

// Define the tests, we want them to run as a nested test so we only clean up the 
// db connection once
var tests = testCase({
  setUp: function(callback) {
    client.open(function(err, db_p) {
      if(numberOfTestsRun == 0) {
        // client.dropDatabase(function(err, done) {
          callback();
        // });        
      } else {
        // Start tests
        callback();        
      }
    });
  },
  
  tearDown: function(callback) {
    numberOfTestsRun = numberOfTestsRun - 1;
    // Drop the database and close it
    if(numberOfTestsRun <= 0) {
      // client.dropDatabase(function(err, done) {
        client.close();
        callback();
      // });        
    } else {
      client.close();
      callback();        
    }      
  },

  // Test clearing out of the collection
  shouldCorrectlyClearOutCollection : function(test) {
    client.createCollection('test_clear', function(err, r) {
      client.collection('test_clear', function(err, collection) {
        collection.insert({i:1}, function(err, ids) {
          collection.insert({i:2}, function(err, ids) {
            collection.count(function(err, count) {
              test.equal(2, count);
              // Clear the collection
              collection.remove({}, {safe:true}, function(err, result) {
                test.equal(2, result);
                
                collection.count(function(err, count) {
                  test.equal(0, count);
                  // Let's close the db
                  test.done();
                });
              });
            });
          });
        });
      });
    });    
  }
})

// Stupid freaking workaround due to there being no way to run setup once for each suite
var numberOfTestsRun = Object.keys(tests).length;
// Assign out tests
module.exports = tests;

==> mongodb-0.9.7-1.1.tgz: package/test/remove_test.js <==
var mongodb = process.env['TEST_NATIVE'] != null ? require('../lib/mongodb').native() : require('../lib/mongodb').pure();

var testCase = require('../deps/nodeunit').testCase,
  debug = require('util').debug,
  inspect = require('util').inspect,
  nodeunit = require('../deps/nodeunit'),
  gleak = require('../tools/gleak'),
  Db = mongodb.Db,
  Cursor = mongodb.Cursor,
  Collection = mongodb.Collection,
  Server = mongodb.Server;

var MONGODB = 'integration_tests';
var client = new Db(MONGODB, new Server("127.0.0.1", 27017, {auto_reconnect: true, poolSize: 4}), {native_parser: (process.env['TEST_NATIVE'] != null)});

// Define the tests, we want them to run as a nested test so we only clean up the 
// db connection once
var tests = testCase({
  setUp: function(callback) {
    client.open(function(err, db_p) {
      if(numberOfTestsRun == Object.keys(tests).length) {
        // If first test drop the db
        client.dropDatabase(function(err, done) {
          callback();
        });                
      } else {
        return callback();        
      }      
    });
  },
  
  tearDown: function(callback) {
    numberOfTestsRun = numberOfTestsRun - 1;
    // Drop the database and close it
    if(numberOfTestsRun <= 0) {
      // client.dropDatabase(function(err, done) {
        client.close();
        callback();
      // });        
    } else {
      client.close();
      callback();        
    }      
  },

  // Test clearing out of the collection
  shouldCorrectlyClearOutCollection : function(test) {
    client.createCollection('test_clear', function(err, r) {
      client.collection('test_clear', function(err, collection) {
        collection.insert({i:1}, {safe:true}, function(err, ids) {
          collection.insert({i:2}, {safe:true}, function(err, ids) {
            collection.count(function(err, count) {
              test.equal(2, count);
              // Clear the collection
              collection.remove({}, {safe:true}, function(err, result) {
                test.equal(2, result);
                
                collection.count(function(err, count) {
                  test.equal(0, count);
                  // Let's close the db
                  test.done();
                });
              });
            });
          });
        });
      });
    });    
  },

  noGlobalsLeaked : function(test) {
    var leaks = gleak.detectNew();
    test.equal(0, leaks.length, "global var leak detected: " + leaks.join(', '));
    test.done();
  }
})

// Stupid freaking workaround due to there being no way to run setup once for each suite
var numberOfTestsRun = Object.keys(tests).length;
// Assign out tests
module.exports = tests;
